@@ -16,6 +16,7 @@
 
 #include <config.h>
 #include <gtk/gtk.h>
+#include <data/file-name.h>
 #include "window-manager.h"
 #include "output-viewer.h"
 #include "helper.h"
@@ -62,7 +63,7 @@ on_delete (GtkWidget *w, GdkEvent *event, gpointer user_data)
 
   the_output_viewer = NULL;
 
-  unlink (OUTPUT_FILE_NAME);
+  unlink (output_file_name ());
 
   return FALSE;
 }
@@ -181,7 +182,7 @@ reload_the_viewer (void)
   struct stat buf;
 
   /* If there is no output, then don't do anything */
-  if (0 != stat (OUTPUT_FILE_NAME, &buf))
+  if (0 != stat (output_file_name (), &buf))
     return ;
 
   if ( NULL == the_output_viewer )
@@ -194,6 +195,7 @@ reload_the_viewer (void)
 }
 
 
+
 void
 reload_viewer (struct output_viewer *ov)
 {
@@ -222,10 +224,10 @@ reload_viewer (struct output_viewer *ov)
   */
   {
     GtkTextIter start_iter;
-    FILE *fp = fopen (OUTPUT_FILE_NAME, "r");
+    FILE *fp = fopen (output_file_name (), "r");
     if ( !fp)
       {
-	g_print ("Cannot open %s\n", OUTPUT_FILE_NAME);
+	g_warning ("Cannot open %s\n", output_file_name ());
 	return;
       }
 
@@ -248,10 +250,10 @@ reload_viewer (struct output_viewer *ov)
   {
     if ( ov->fp == NULL)
       {
-	ov->fp = fopen (OUTPUT_FILE_NAME, "r");
+	ov->fp = fopen (output_file_name (), "r");
 	if ( ov->fp == NULL)
 	  {
-	    g_print ("Cannot open %s\n", OUTPUT_FILE_NAME);
+	    g_warning ("Cannot open %s\n", output_file_name ());
 	    return;
 	  }
       }
@@ -276,4 +278,17 @@ reload_viewer (struct output_viewer *ov)
 }
 
 
+#define OUTPUT_FILE_NAME "psppire.txt"
 
+const char *
+output_file_name (void)
+{
+  const char *dir = default_output_path ();
+  static char *filename = NULL;
+
+  if ( NULL == filename )
+    filename = xasprintf ("%s%s", dir, OUTPUT_FILE_NAME);
+
+
+  return filename;
+}
